'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createPluggableMiddleware;

var _lodash = require('lodash');

/**
 * This is used for hot reloading redux middleware.
 *
 * let hmrMiddleware = createPluggableMiddleware(myMiddleware);
 * // hmrMiddleware can be used with applyMiddleware() just like anything else.
 * // but later if you need to replace it you can do:
 * hmrMiddleware.replaceMiddleware(myNewMiddleware);
 */
function createPluggableMiddleware(middleware) {
  var result = function result(store) {
    return function (next) {
      var dispatch = (0, _lodash.memoize)(function (middleware) {
        return middleware ? middleware(store)(next) : next;
      });
      return function (action) {
        return dispatch(middleware)(action);
      };
    };
  };
  result.replaceMiddleware = function (nextMiddleware) {
    return middleware = nextMiddleware;
  };
  return result;
}